### Name: FRBmultiregGS
### Title: GS-Estimates for multivariate regression with bootstrap
###   confidence intervals
### Aliases: FRBmultiregGS FRBmultiregGS.default FRBmultiregGS.formula
### Keywords: multivariate robust

### ** Examples

data(schooldata)
school.x <- data.matrix(schooldata[,1:5])
school.y <- data.matrix(schooldata[,6:8])

#computes 25% breakdown point GS-estimate and 99% confidence intervals 
#based on 999 bootstrap samples:
GSres <- FRBmultiregGS(school.x, school.y, R=999, bdp = 0.25, conf = 0.99)
#or, equivalently,
GSres <- FRBmultiregGS(cbind(reading,mathematics,selfesteem)~., data=schooldata, 
          R=999, bdp = 0.25, conf = 0.99)

#the print method displays the coefficients with their bootstrap standard errors
GSres

#the summary function additionally displays the confidence intervals 
#("BCA" method by default)
summary(GSres)

summary(GSres, confmethod="basic")

#ask explicitely for the coefficient matrix:
GSres$Beta
#or for the error covariance matrix:
GSres$Sigma
                                                              
#plot some bootstrap histograms for the coefficient estimates 
#(with "BCA" intervals by default) 
plot(GSres, which=2, expl=c("education", "occupation"), resp=c("selfesteem","reading"))

#plot bootstrap histograms for all coefficient estimates
plot(GSres, which=2)
#possibly the plot-function has made a selection of coefficients to plot here, 
#since 'all' may have been too many to fit on one page, see help(plot.FRBmultireg); 
#this is platform-dependent

# diagnostic plot for outlier detection:
plot(GSres, which=1)
# this may take a while, since the function needs to compute GS-estimates 
# for the X matrix



